package com.sooka.system.service;

import java.util.List;
import com.sooka.system.domain.TgjjDwzhxx;

/**
 * 单位账户信息Service接口
 * 
 * @author lei
 * @date 2021-11-16
 */
public interface ITgjjDwzhxxService 
{
    /**
     * 查询单位账户信息
     * 
     * @param ID 单位账户信息ID
     * @return 单位账户信息
     */
    public TgjjDwzhxx selectTgjjDwzhxxById(Long ID);

    /**
     * 查询单位账户信息列表
     * 
     * @param tgjjDwzhxx 单位账户信息
     * @return 单位账户信息集合
     */
    public List<TgjjDwzhxx> selectTgjjDwzhxxList(TgjjDwzhxx tgjjDwzhxx);

    /**
     * 新增单位账户信息
     * 
     * @param tgjjDwzhxx 单位账户信息
     * @return 结果
     */
    public int insertTgjjDwzhxx(TgjjDwzhxx tgjjDwzhxx);

    /**
     * 修改单位账户信息
     * 
     * @param tgjjDwzhxx 单位账户信息
     * @return 结果
     */
    public int updateTgjjDwzhxx(TgjjDwzhxx tgjjDwzhxx);

    /**
     * 批量删除单位账户信息
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTgjjDwzhxxByIds(String ids);

    /**
     * 删除单位账户信息信息
     * 
     * @param ID 单位账户信息ID
     * @return 结果
     */
    public int deleteTgjjDwzhxxById(Long ID);
}
